Class InstrumentedSutStarter

java.lang.Object
org.evomaster.client.java.controller.InstrumentedSutStarter

public class InstrumentedSutStarter extends Object
Class responsible to handle the SutController in a way in which bytecode instrumentation is activated. Note: instrumentation is needed when generating tests with EvoMaster, but not when we run the generated tests.
  • Field Details

    • JDK_17_JVM_OPTIONS

      public static final String JDK_17_JVM_OPTIONS
      Annoying settings needed for JDK 17 :( Update docs/jdks.md if this changes
      See Also:
  • Constructor Details

    • InstrumentedSutStarter

      public InstrumentedSutStarter(SutController sutController)
  • Method Details

    • loadAgent

      public static void loadAgent()
    • start

      public boolean start()
    • stop

      public boolean stop()
    • getControllerServerPort

      public int getControllerServerPort()