Interface IndividualExpectation

All Known Implementing Classes:
ExpectationHandler

public interface IndividualExpectation
  • Method Summary

    Modifier and Type
    Method
    Description
    that(boolean active, boolean condition)
    An individual expectation from a call result.
    that(boolean active, Method method, Object[] args)
    An individual expectation from a call result.
  • Method Details

    • that

      IndividualExpectation that(boolean active, boolean condition)
      An individual expectation from a call result.
      Parameters:
      active - is the expectation active. If active, and the condition is false, an Exception will be raised.
      condition - is the condition to be checked. If the expectation is not [active], the truth value of the condition is not relevant. Additional functions can/will be developed.
    • that

      IndividualExpectation that(boolean active, Method method, Object[] args)
      An individual expectation from a call result.
      Parameters:
      active - is the expectation active. If active, and the condition is false, an Exception will be raised.
      method - is should be invoked if active (and any other conditions are met). The idea is to allow the use of Hamcrest Matchers and Rest Assured assertions. Additional functions can/will be developed.