Uses of Package
org.evomaster.client.java.controller.internal
Packages that use org.evomaster.client.java.controller.internal
Package
Description
-
Classes in org.evomaster.client.java.controller.internal used by org.evomaster.client.java.controllerClassDescriptionAbstract class used to connect to the EvoMaster process, and that is responsible to start/stop/restart the tested application, ie the system under test (SUT)
-
Classes in org.evomaster.client.java.controller.internal used by org.evomaster.client.java.controller.internalClassDescriptionAbstract class used to connect to the EvoMaster process, and that is responsible to start/stop/restart the tested application, ie the system under test (SUT)