Class ElemMatchOperation

java.lang.Object
org.evomaster.client.java.controller.mongo.operations.QueryOperation
org.evomaster.client.java.controller.mongo.operations.ElemMatchOperation

public class ElemMatchOperation extends QueryOperation
Represent $elemMatch operation. Selects documents if element in the array field matches all the specified $elemMatch conditions. Here it only has one condition to match implementation in "com.mongodb.client.model.Filters"
  • Constructor Details

  • Method Details