Class LessThanEqualsOperation<V>
java.lang.Object
org.evomaster.client.java.controller.mongo.operations.QueryOperation
org.evomaster.client.java.controller.mongo.operations.ComparisonOperation<V>
org.evomaster.client.java.controller.mongo.operations.LessThanEqualsOperation<V>
Represent $lte operation.
Selects the documents where the value of the field is less than or equal to a specified value
-
Constructor Summary
Constructors -
Method Summary
Methods inherited from class org.evomaster.client.java.controller.mongo.operations.ComparisonOperation
getFieldName, getValue
-
Constructor Details
-
LessThanEqualsOperation
-