Class NotEqualsOperation<V>


public class NotEqualsOperation<V> extends ComparisonOperation<V>
Represent $ne operation. Selects the documents where the value of the field is not equal to the specified value. This includes documents that do not contain the field.
  • Constructor Details

    • NotEqualsOperation

      public NotEqualsOperation(String fieldName, V value)