Package org.evomaster.client.java.controller
package org.evomaster.client.java.controller
-
ClassDescriptioncontains a set of method to customize info for testing need to check with Andrea if putting them in this interface or moving them to SutControllerutil class for handling dtoMain class used to implement an EvoMaster Driver.Class responsible to handle the SutController in a way in which bytecode instrumentation is activated.Base interface used to control the System Under Test (SUT) from the generated tests.