Uses of Package
org.evomaster.client.java.controller
Packages that use org.evomaster.client.java.controller
Package
Description
-
Classes in org.evomaster.client.java.controller used by org.evomaster.client.java.controllerClassDescriptioncontains a set of method to customize info for testing need to check with Andrea if putting them in this interface or moving them to SutControllerBase interface used to control the System Under Test (SUT) from the generated tests.
-
Classes in org.evomaster.client.java.controller used by org.evomaster.client.java.controller.internalClassDescriptioncontains a set of method to customize info for testing need to check with Andrea if putting them in this interface or moving them to SutControllerBase interface used to control the System Under Test (SUT) from the generated tests.