java.lang.Object
org.evomaster.client.java.controller.problem.ProblemInfo
Direct Known Subclasses:
GraphQlProblem, RestProblem, RPCProblem, WebProblem

public abstract class ProblemInfo extends Object
Depending on which kind of SUT we are dealing with (eg, REST, GraphQL or SPA frontend), there is different info that must be provided. However, some time of info might be the same for all these kinds of problems. Created by arcuri82 on 05-Nov-18.
  • Field Details

    • servicesToNotMock

      protected final List<ExternalService> servicesToNotMock
      In some cases, we might want to replace and mock away some interactions with external services (eg, REST APIs). Here, we can specify which ones should NOT be mocked, and rather use the actual services.
  • Constructor Details

    • ProblemInfo

      public ProblemInfo(List<ExternalService> servicesToNotMock)
    • ProblemInfo

      public ProblemInfo()
  • Method Details