java.lang.Object
org.evomaster.client.java.controller.problem.ProblemInfo
org.evomaster.client.java.controller.problem.RPCProblem

public class RPCProblem extends ProblemInfo
define RPCProblem used in driver
  • Constructor Details

    • RPCProblem

      public RPCProblem(Class<T> interfaceClass, K client, org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType type)
      Parameters:
      interfaceClass - an interface with API definition
      client - an actual client library for the API
      type - the type of RPC system
    • RPCProblem

      public RPCProblem(Map<String,Object> mapOfInterfaceAndClient)
      Parameters:
      mapOfInterfaceAndClient - a map of interfaces with their corresponding client
    • RPCProblem

      public RPCProblem(Map<String,Object> mapOfInterfaceAndClient, org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType type)
      Parameters:
      mapOfInterfaceAndClient - a map of interfaces with their corresponding client
      type - is RPC type
    • RPCProblem

      public RPCProblem(Map<String,Object> mapOfInterfaceAndClient, Map<String,List<String>> skipEndpointsByName, Map<String,List<String>> skipEndpointsByAnnotation, Map<String,List<String>> involveEndpointsByName, Map<String,List<String>> involveEndpointsByAnnotation, org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType type)
      Parameters:
      mapOfInterfaceAndClient - a map of interfaces with their corresponding client
      skipEndpointsByName - is a map of endpoints to be skipped for each interface by endpoint name
      skipEndpointsByAnnotation - is a map of endpoints to be skipped for each interface by endpoint annotation
      involveEndpointsByName - is a map of endpoints to be involved for each interface by endpoint name
      involveEndpointsByAnnotation - is a map of endpoints to be involved for each interface by endpoint annotation
      type - is RPC type
  • Method Details

    • getKeysOfMapOfInterfaceAndClient

      public Set<String> getKeysOfMapOfInterfaceAndClient()
      Returns:
      a set of interface names for the RPC problem
    • getType

      public org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType getType()
      Returns:
      type of the RPC interface
    • getMapOfInterfaceAndClient

      public Map<String,Object> getMapOfInterfaceAndClient()
    • getSkipEndpointsByName

      public Map<String,List<String>> getSkipEndpointsByName()
    • getSkipEndpointsByAnnotation

      public Map<String,List<String>> getSkipEndpointsByAnnotation()
    • getInvolveEndpointsByName

      public Map<String,List<String>> getInvolveEndpointsByName()
    • getInvolveEndpointsByAnnotation

      public Map<String,List<String>> getInvolveEndpointsByAnnotation()
    • getClient

      public Object getClient(String interfaceId)
      Parameters:
      interfaceId - is the full name of the interface
      Returns:
      the client based on the interface name
    • withServicesToNotMock

      public RPCProblem withServicesToNotMock(List<ExternalService> servicesToNotMock)
      Specified by:
      withServicesToNotMock in class ProblemInfo