Uses of Class
org.evomaster.client.java.controller.problem.ExternalService
Packages that use ExternalService
-
Uses of ExternalService in org.evomaster.client.java.controller.problem
Fields in org.evomaster.client.java.controller.problem with type parameters of type ExternalServiceModifier and TypeFieldDescriptionprotected final List<ExternalService>ProblemInfo.servicesToNotMockIn some cases, we might want to replace and mock away some interactions with external services (eg, REST APIs).Methods in org.evomaster.client.java.controller.problem that return types with arguments of type ExternalServiceMethod parameters in org.evomaster.client.java.controller.problem with type arguments of type ExternalServiceModifier and TypeMethodDescriptionGraphQlProblem.withServicesToNotMock(List<ExternalService> servicesToNotMock) abstract ProblemInfoProblemInfo.withServicesToNotMock(List<ExternalService> servicesToNotMock) RestProblem.withServicesToNotMock(List<ExternalService> servicesToNotMock) RPCProblem.withServicesToNotMock(List<ExternalService> servicesToNotMock) WebProblem.withServicesToNotMock(List<ExternalService> servicesToNotMock) Constructor parameters in org.evomaster.client.java.controller.problem with type arguments of type ExternalService