Class AssertionsUtil

java.lang.Object
org.evomaster.client.java.controller.problem.rpc.AssertionsUtil

public class AssertionsUtil extends Object
  • Constructor Details

    • AssertionsUtil

      public AssertionsUtil()
  • Method Details

    • getAssertionsWithComment

      public static boolean getAssertionsWithComment(String assertionScript)
      there might exist dependent or random values they could be changed over time, then for such, we might avoid creating assertions for it, in this case, we still generate such assertions but comment them out
      Parameters:
      assertionScript - an assertion
      Returns:
      if comment it out