Class JavaXConstraintHandler

java.lang.Object
org.evomaster.client.java.controller.problem.rpc.JavaXConstraintHandler

public class JavaXConstraintHandler extends Object
this class is to handle constraints defined with javax.validation.constraints following the link https://javaee.github.io/javaee-spec/javadocs/javax/validation/constraints/package-summary.html
  • Constructor Details

    • JavaXConstraintHandler

      public JavaXConstraintHandler()
  • Method Details

    • handleParam

      public static void handleParam(NamedTypedValue namedTypedValue, Annotation annotation)
      set constraints of the param based on the given annotation
      Parameters:
      namedTypedValue - is the extracted param
      annotation - is the annotation to be handled