Class Protobuf3Field

java.lang.Object
org.evomaster.client.java.controller.problem.rpc.Protobuf3Field

public class Protobuf3Field extends Object
this class presents extracted info of a field of protobuf dto
  • Field Details

    • fieldName

      public String fieldName
      name
    • fieldType

      public Class<?> fieldType
      type
    • genericType

      public Type genericType
      generic type if it exists, such as for Map, List
    • setterName

      public String setterName
      name of corresponding setter
    • setterInputParams

      public Class<?>[] setterInputParams
      types of input parameters of the setter the input parameter might not be consistent with the fieldType in gRPC the type could be defined with its supertype then we need such explicit info in order to get the setter For instance, the fieldType is List, and the input type is Iterator
    • getterName

      public String getterName
      name of getter
  • Constructor Details

    • Protobuf3Field

      public Protobuf3Field()