Class RPCExceptionHandler

java.lang.Object
org.evomaster.client.java.controller.problem.rpc.RPCExceptionHandler

public class RPCExceptionHandler extends Object
handle RPC exception, for instance - extract possible category eg, application, protocol, if possible - extract exception info, eg, customized exception, message, or status code
  • Constructor Details

    • RPCExceptionHandler

      public RPCExceptionHandler()
  • Method Details

    • handle

      public static void handle(Object e, org.evomaster.client.java.controller.api.dto.ActionResponseDto dto, EndpointSchema endpointSchema, org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType type, Map<Class,Integer> levelsMap)
      Parameters:
      e - is an exception instance thrown after the endpoint invocation
      dto - represents the endpoint which was invoked
      endpointSchema - is the schema of the endpoint
      type - is the RPC type