Package org.evomaster.client.java.controller.problem.rpc
package org.evomaster.client.java.controller.problem.rpc
-
ClassDescriptiona set of util for generating instance creation and assertion with java in tests in order to make endpoint invocationa customized criteria to check if a field is required or (not nullable) with the following three situations - only [annotationType] is specified, then the field with such annotation would be considered as `required` - [annotationType], [annotationMethod] and [equalsTo] are specified, then the field is considered as `required` only if the field is applied with the annotation and the method of the annotation returns the same value as [equalsTo]this class is to handle constraints defined with javax.validation.constraints following the link https://javaee.github.io/javaee-spec/javadocs/javax/validation/constraints/package-summary.htmlthis class presents extracted info of a field of protobuf dtocreated by manzhang on 2021/11/4handle RPC exception, for instance - extract possible category eg, application, protocol, if possible - extract exception info, eg, customized exception, message, or status code