Uses of Package
org.evomaster.client.java.controller.problem.rpc
Packages that use org.evomaster.client.java.controller.problem.rpc
Package
Description
-
Classes in org.evomaster.client.java.controller.problem.rpc used by org.evomaster.client.java.controllerClassDescriptiona customized criteria to check if a field is required or (not nullable) with the following three situations - only [annotationType] is specified, then the field with such annotation would be considered as `required` - [annotationType], [annotationMethod] and [equalsTo] are specified, then the field is considered as `required` only if the field is applied with the annotation and the method of the annotation returns the same value as [equalsTo]
-
Classes in org.evomaster.client.java.controller.problem.rpc used by org.evomaster.client.java.controller.internalClassDescriptiona customized criteria to check if a field is required or (not nullable) with the following three situations - only [annotationType] is specified, then the field with such annotation would be considered as `required` - [annotationType], [annotationMethod] and [equalsTo] are specified, then the field is considered as `required` only if the field is applied with the annotation and the method of the annotation returns the same value as [equalsTo]
-
Classes in org.evomaster.client.java.controller.problem.rpc used by org.evomaster.client.java.controller.problem.rpcClassDescriptiona customized criteria to check if a field is required or (not nullable) with the following three situations - only [annotationType] is specified, then the field with such annotation would be considered as `required` - [annotationType], [annotationMethod] and [equalsTo] are specified, then the field is considered as `required` only if the field is applied with the annotation and the method of the annotation returns the same value as [equalsTo]