java.lang.Object
org.evomaster.client.java.controller.redis.RedisInfo

public class RedisInfo extends Object
This class will contain all necessary information from Redis to perform the distance calculation for a given command. Hence, RedisHeuristicCalculator will be decoupled from Redis. There'll be no need to call Redis to calculate distances.