Class RedisValueData

java.lang.Object
org.evomaster.client.java.controller.redis.RedisValueData

public class RedisValueData extends Object
This class will hold the data associated to the value for a given key in Redis. Fields or members will be set depending on the type of key. String keys may have a String value in the future, but currently it is not needed to store that information. Set keys will have the set members. Hash keys will have the fields.
  • Constructor Details

    • RedisValueData

      public RedisValueData(Map<String,String> fields)
    • RedisValueData

      public RedisValueData(Set<String> members)
  • Method Details