java.lang.Object
org.evomaster.client.java.controller.redis.dsl.RedisDsl
All Implemented Interfaces:
RedisSequenceDsl, RedisStatementDsl

public class RedisDsl extends Object implements RedisSequenceDsl, RedisStatementDsl
DSL (Domain Specific Language) for insertions on the Redis Database.
  • Method Details

    • redis

      public static RedisSequenceDsl redis()
      Returns:
      a DSL object to create Redis operations
    • redis

      @SafeVarargs public static RedisSequenceDsl redis(List<RedisInsertionDto>... previous)
      Parameters:
      previous - a DSL object which is executed in the front of this
      Returns:
      a DSL object to create Redis operations
    • set

      public RedisStatementDsl set(String key, String value)
      Description copied from interface: RedisSequenceDsl
      A SET operation on the Redis database.
      Specified by:
      set in interface RedisSequenceDsl
      Parameters:
      key - the key under which the value will be stored in Redis
      value - the string value to store
      Returns:
      a statement object on which the sequence can be continued or closed
    • and

      public RedisSequenceDsl and()
      Description copied from interface: RedisStatementDsl
      Close the current statement and return to the sequence, allowing further Redis commands to be chained.
      Specified by:
      and in interface RedisStatementDsl
      Returns:
      the sequence object on which new Redis commands can be added
    • dtos

      public List<RedisInsertionDto> dtos()
      Description copied from interface: RedisStatementDsl
      Build the DTOs (Data Transfer Object) from this DSL, closing it (i.e., not usable any longer).
      Specified by:
      dtos in interface RedisStatementDsl
      Returns:
      a list of DTOs representing all the insertion Redis commands defined in this DSL.