Interface RedisStatementDsl

All Known Implementing Classes:
RedisDsl

public interface RedisStatementDsl
  • Method Summary

    Modifier and Type
    Method
    Description
    and()
    Close the current statement and return to the sequence, allowing further Redis commands to be chained.
    Build the DTOs (Data Transfer Object) from this DSL, closing it (i.e., not usable any longer).
  • Method Details

    • and

      Close the current statement and return to the sequence, allowing further Redis commands to be chained.
      Returns:
      the sequence object on which new Redis commands can be added
    • dtos

      Build the DTOs (Data Transfer Object) from this DSL, closing it (i.e., not usable any longer).
      Returns:
      a list of DTOs representing all the insertion Redis commands defined in this DSL.