Package org.evomaster.client.java.controller.redis
package org.evomaster.client.java.controller.redis
-
ClassesClassDescriptionClass used to execute Redis commandsThis class will contain all necessary information from Redis to perform the distance calculation for a given command.Utils class for auxiliary operations in Redis heuristic value calculations.This class will hold the data associated to the value for a given key in Redis.RedisClient that uses Lettuce dynamically via reflection, avoiding compile-time dependency on Spring or Lettuce.