Class MongoHeuristicsCalculator
java.lang.Object
org.evomaster.client.java.controller.mongo.MongoHeuristicsCalculator
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionMongoHeuristicsCalculator(org.evomaster.client.java.sql.internal.TaintHandler taintHandler) -
Method Summary
Modifier and TypeMethodDescriptiondoublecomputeExpression(Object query, Object doc) Compute a "branch" distance heuristics.
-
Field Details
-
MIN_DISTANCE_TO_TRUE_VALUE
public static final double MIN_DISTANCE_TO_TRUE_VALUE- See Also:
-
-
Constructor Details
-
MongoHeuristicsCalculator
public MongoHeuristicsCalculator() -
MongoHeuristicsCalculator
public MongoHeuristicsCalculator(org.evomaster.client.java.sql.internal.TaintHandler taintHandler)
-
-
Method Details
-
computeExpression
Compute a "branch" distance heuristics.- Parameters:
query- the QUERY clause which we want to resolve as truedoc- a document in the database for which we want to calculate the distance- Returns:
- a branch distance, where 0 means that the document would make the QUERY resolve as true
-