Class MongoDsl
java.lang.Object
org.evomaster.client.java.controller.mongo.dsl.MongoDsl
- All Implemented Interfaces:
MongoSequenceDsl,MongoStatementDsl
DSL (Domain Specific Language) for operations on
the Mongo Database
-
Method Summary
Modifier and TypeMethodDescriptionand()Close the current statementAdd a value to insertdtos()Build the DTOs (Data Transfer Object) from this DSL, closing it (ie, not usable any longer).insertInto(String databaseName, String collectionName) An insertion operation on the Mongo Database (MongoDB)static MongoSequenceDslmongo()static MongoSequenceDslmongo(List<MongoInsertionDto>... previous)
-
Method Details
-
mongo
- Returns:
- a DSL object to create MONGO operations
-
mongo
- Parameters:
previous- a DSL object which is executed in the front of this- Returns:
- a DSL object to create MONGO operations
-
insertInto
Description copied from interface:MongoSequenceDslAn insertion operation on the Mongo Database (MongoDB)- Specified by:
insertIntoin interfaceMongoSequenceDsl- Parameters:
databaseName- the target database in the MongoDBcollectionName- the target collection in the MongoDB- Returns:
- a statement in which it can be specified the values to add
-
d
Description copied from interface:MongoStatementDslAdd a value to insert- Specified by:
din interfaceMongoStatementDsl- Parameters:
printableValue- the value that is going to be inserted, as it would be printed as string. This means that 5 is represented with "5", whereas "5" with "'5'"- Returns:
- the continuation of this statement, in which more values can be added
-
and
Description copied from interface:MongoStatementDslClose the current statement- Specified by:
andin interfaceMongoStatementDsl- Returns:
- the sequence object on which new Mongo commands can be added
-
dtos
Description copied from interface:MongoStatementDslBuild the DTOs (Data Transfer Object) from this DSL, closing it (ie, not usable any longer).- Specified by:
dtosin interfaceMongoStatementDsl- Returns:
- a list of DTOs representing all the insertion MONGO commands defined in this DSL.
-