Interface MongoStatementDsl
- All Known Implementing Classes:
MongoDsl
public interface MongoStatementDsl
-
Method Details
-
d
Add a value to insert- Parameters:
printableValue- the value that is going to be inserted, as it would be printed as string. This means that 5 is represented with "5", whereas "5" with "'5'"- Returns:
- the continuation of this statement, in which more values can be added
-
and
MongoSequenceDsl and()Close the current statement- Returns:
- the sequence object on which new Mongo commands can be added
-
dtos
List<MongoInsertionDto> dtos()Build the DTOs (Data Transfer Object) from this DSL, closing it (ie, not usable any longer).- Returns:
- a list of DTOs representing all the insertion MONGO commands defined in this DSL.
-