Class RPCProblem
java.lang.Object
org.evomaster.client.java.controller.problem.ProblemInfo
org.evomaster.client.java.controller.problem.RPCProblem
define RPCProblem used in driver
-
Field Summary
Fields inherited from class org.evomaster.client.java.controller.problem.ProblemInfo
servicesToNotMock -
Constructor Summary
ConstructorsConstructorDescriptionRPCProblem(Class<T> interfaceClass, K client, org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType type) RPCProblem(Map<String, Object> mapOfInterfaceAndClient) RPCProblem(Map<String, Object> mapOfInterfaceAndClient, Map<String, List<String>> skipEndpointsByName, Map<String, List<String>> skipEndpointsByAnnotation, Map<String, List<String>> involveEndpointsByName, Map<String, List<String>> involveEndpointsByAnnotation, org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType type) RPCProblem(Map<String, Object> mapOfInterfaceAndClient, org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType type) -
Method Summary
Modifier and TypeMethodDescriptionorg.evomaster.client.java.controller.api.dto.problem.rpc.RPCTypegetType()withServicesToNotMock(List<ExternalService> servicesToNotMock) Methods inherited from class org.evomaster.client.java.controller.problem.ProblemInfo
getServicesToNotMock
-
Constructor Details
-
RPCProblem
public RPCProblem(Class<T> interfaceClass, K client, org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType type) - Parameters:
interfaceClass- an interface with API definitionclient- an actual client library for the APItype- the type of RPC system
-
RPCProblem
- Parameters:
mapOfInterfaceAndClient- a map of interfaces with their corresponding client
-
RPCProblem
public RPCProblem(Map<String, Object> mapOfInterfaceAndClient, org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType type) - Parameters:
mapOfInterfaceAndClient- a map of interfaces with their corresponding clienttype- is RPC type
-
RPCProblem
public RPCProblem(Map<String, Object> mapOfInterfaceAndClient, Map<String, List<String>> skipEndpointsByName, Map<String, List<String>> skipEndpointsByAnnotation, Map<String, List<String>> involveEndpointsByName, Map<String, List<String>> involveEndpointsByAnnotation, org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType type) - Parameters:
mapOfInterfaceAndClient- a map of interfaces with their corresponding clientskipEndpointsByName- is a map of endpoints to be skipped for each interface by endpoint nameskipEndpointsByAnnotation- is a map of endpoints to be skipped for each interface by endpoint annotationinvolveEndpointsByName- is a map of endpoints to be involved for each interface by endpoint nameinvolveEndpointsByAnnotation- is a map of endpoints to be involved for each interface by endpoint annotationtype- is RPC type
-
-
Method Details
-
getKeysOfMapOfInterfaceAndClient
- Returns:
- a set of interface names for the RPC problem
-
getType
public org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType getType()- Returns:
- type of the RPC interface
-
getMapOfInterfaceAndClient
-
getSkipEndpointsByName
-
getSkipEndpointsByAnnotation
-
getInvolveEndpointsByName
-
getInvolveEndpointsByAnnotation
-
getClient
- Parameters:
interfaceId- is the full name of the interface- Returns:
- the client based on the interface name
-
withServicesToNotMock
- Specified by:
withServicesToNotMockin classProblemInfo
-