Class RestProblem
java.lang.Object
org.evomaster.client.java.controller.problem.ProblemInfo
org.evomaster.client.java.controller.problem.RestProblem
Created by arcuri82 on 05-Nov-18.
-
Field Summary
Fields inherited from class org.evomaster.client.java.controller.problem.ProblemInfo
servicesToNotMock -
Constructor Summary
ConstructorsConstructorDescriptionRestProblem(String openApiUrl, List<String> endpointsToSkip) RestProblem(String openApiUrl, List<String> endpointsToSkip, String openApiSchema) RestProblem(String openApiUrl, List<String> endpointsToSkip, String openApiSchema, List<ExternalService> servicesToNotMock, List<RestDerivedParam> derivedParams) -
Method Summary
Modifier and TypeMethodDescriptionwithDerivedParams(List<RestDerivedParam> derivedParams) withServicesToNotMock(List<ExternalService> servicesToNotMock) Methods inherited from class org.evomaster.client.java.controller.problem.ProblemInfo
getServicesToNotMock
-
Constructor Details
-
RestProblem
-
RestProblem
-
RestProblem
public RestProblem(String openApiUrl, List<String> endpointsToSkip, String openApiSchema, List<ExternalService> servicesToNotMock, List<RestDerivedParam> derivedParams) - Parameters:
openApiUrl- Provide the URL of where the OpenAPI schema can be found.endpointsToSkip- When testing a REST API, there might be some endpoints that are not so important to test. For example, in Spring, health-check endpoints like "/heapdump" are not so interesting to test, and they can be very expensive to run. Here can specify a list of endpoints (as defined in the schema) to skip.openApiSchema- the actual schema, as a string. Note, if this specified, then openApiUrl must be null
-
-
Method Details
-
withServicesToNotMock
- Specified by:
withServicesToNotMockin classProblemInfo
-
withDerivedParams
-
getOpenApiUrl
-
getEndpointsToSkip
-
getOpenApiSchema
-
getDerivedParams
-