Class JavaXConstraintHandler
java.lang.Object
org.evomaster.client.java.controller.problem.rpc.JavaXConstraintHandler
this class is to handle constraints defined with javax.validation.constraints
following the link
https://javaee.github.io/javaee-spec/javadocs/javax/validation/constraints/package-summary.html
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic voidhandleParam(NamedTypedValue namedTypedValue, Annotation annotation) set constraints of the param based on the given annotation
-
Constructor Details
-
JavaXConstraintHandler
public JavaXConstraintHandler()
-
-
Method Details
-
handleParam
set constraints of the param based on the given annotation- Parameters:
namedTypedValue- is the extracted paramannotation- is the annotation to be handled
-