Class Protobuf3Field
java.lang.Object
org.evomaster.client.java.controller.problem.rpc.Protobuf3Field
this class presents extracted info of a field of protobuf dto
-
Field Summary
FieldsModifier and TypeFieldDescriptionnameClass<?>typegeneric type if it exists, such as for Map, Listname of getterClass<?>[]types of input parameters of the setter the input parameter might not be consistent with the fieldType in gRPC the type could be defined with its supertype then we need such explicit info in order to get the setter For instance, the fieldType is List, and the input type is Iteratorname of corresponding setter -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
fieldName
name -
fieldType
type -
genericType
generic type if it exists, such as for Map, List -
setterName
name of corresponding setter -
setterInputParams
types of input parameters of the setter the input parameter might not be consistent with the fieldType in gRPC the type could be defined with its supertype then we need such explicit info in order to get the setter For instance, the fieldType is List, and the input type is Iterator -
getterName
name of getter
-
-
Constructor Details
-
Protobuf3Field
public Protobuf3Field()
-