Class RPCExceptionHandler
java.lang.Object
org.evomaster.client.java.controller.problem.rpc.RPCExceptionHandler
handle RPC exception, for instance
- extract possible category eg, application, protocol, if possible
- extract exception info, eg, customized exception, message, or status code
-
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
RPCExceptionHandler
public RPCExceptionHandler()
-
-
Method Details
-
handle
public static void handle(Object e, org.evomaster.client.java.controller.api.dto.ActionResponseDto dto, EndpointSchema endpointSchema, org.evomaster.client.java.controller.api.dto.problem.rpc.RPCType type, Map<Class, Integer> levelsMap) - Parameters:
e- is an exception instance thrown after the endpoint invocationdto- represents the endpoint which was invokedendpointSchema- is the schema of the endpointtype- is the RPC type
-