java.lang.Object
org.evomaster.client.java.controller.redis.RedisInfo

public class RedisInfo extends Object
This class will contain all necessary information from Redis to perform the distance calculation for a given command. Hence, RedisHeuristicCalculator will be decoupled from Redis. There'll be no need to call Redis to calculate distances.
  • Constructor Details

    • RedisInfo

      public RedisInfo(String key)
    • RedisInfo

      public RedisInfo(String key, boolean hasField)
    • RedisInfo

      public RedisInfo(String key, String type, Set<String> members)
  • Method Details

    • getKey

      public String getKey()
    • getType

      public String getType()
    • hasField

      public boolean hasField()
    • getMembers

      public Set<String> getMembers()