Class RedisInfo
java.lang.Object
org.evomaster.client.java.controller.redis.RedisInfo
This class will contain all necessary information from Redis to perform the distance calculation for a given command.
Hence, RedisHeuristicCalculator will be decoupled from Redis.
There'll be no need to call Redis to calculate distances.
-
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
RedisInfo
-
RedisInfo
-
RedisInfo
-
-
Method Details
-
getKey
-
getType
-
hasField
public boolean hasField() -
getMembers
-