Class RedisValueData
java.lang.Object
org.evomaster.client.java.controller.redis.RedisValueData
This class will hold the data associated to the value for a given key in Redis.
Fields or members will be set depending on the type of key.
String keys may have a String value in the future, but currently it is not needed to store that information.
Set keys will have the set members. Hash keys will have the fields.
-
Constructor Summary
ConstructorsConstructorDescriptionRedisValueData(Map<String, String> fields) RedisValueData(Set<String> members) -
Method Summary
-
Constructor Details
-
RedisValueData
-
RedisValueData
-
-
Method Details
-
getMembers
-
getFields
-