Class RedisDsl
java.lang.Object
org.evomaster.client.java.controller.redis.dsl.RedisDsl
- All Implemented Interfaces:
RedisSequenceDsl,RedisStatementDsl
DSL (Domain Specific Language) for insertions on
the Redis Database.
-
Method Summary
Modifier and TypeMethodDescriptionand()Close the current statement and return to the sequence, allowing further Redis commands to be chained.dtos()Build the DTOs (Data Transfer Object) from this DSL, closing it (i.e., not usable any longer).static RedisSequenceDslredis()static RedisSequenceDslredis(List<RedisInsertionDto>... previous) A SET operation on the Redis database.
-
Method Details
-
redis
- Returns:
- a DSL object to create Redis operations
-
redis
- Parameters:
previous- a DSL object which is executed in the front of this- Returns:
- a DSL object to create Redis operations
-
set
Description copied from interface:RedisSequenceDslA SET operation on the Redis database.- Specified by:
setin interfaceRedisSequenceDsl- Parameters:
key- the key under which the value will be stored in Redisvalue- the string value to store- Returns:
- a statement object on which the sequence can be continued or closed
-
and
Description copied from interface:RedisStatementDslClose the current statement and return to the sequence, allowing further Redis commands to be chained.- Specified by:
andin interfaceRedisStatementDsl- Returns:
- the sequence object on which new Redis commands can be added
-
dtos
Description copied from interface:RedisStatementDslBuild the DTOs (Data Transfer Object) from this DSL, closing it (i.e., not usable any longer).- Specified by:
dtosin interfaceRedisStatementDsl- Returns:
- a list of DTOs representing all the insertion Redis commands defined in this DSL.
-