Package org.evomaster.client.java.controller.redis
package org.evomaster.client.java.controller.redis
-
ClassesClassDescriptionRedisClient that uses Lettuce dynamically via reflection, avoiding compile-time dependency on Spring or Lettuce.This class will contain all necessary information from Redis to perform the distance calculation for a given command.Utils class for auxiliary operations in Redis heuristic value calculations.